@@ -1,4 +1,4 @@
-# $Id: variogram.gstat.q,v 1.7 2006-02-10 19:01:07 edzer Exp $
+# $Id: variogram.gstat.q,v 1.8 2006-12-10 14:17:17 edzer Exp $
 
 "variogram.gstat" = function (object, ...) {
 	if (!inherits(object, "gstat"))
@@ -8,18 +8,24 @@
 	X = list()
 	beta = list()
 	grid = list()
+	projected = TRUE
 	for (i in seq(along = object$data)) {
 		d = object$data[[i]]
+		if (i > 1 && !equal.projections(object$data[[1]]$data, d$data))
+			stop("data items in gstat object have different coordinate reference systems")
 		raw = gstat.formula(d$formula, d$data)
 		y[[i]] = raw$y
 		locations[[i]] = raw$locations
 		X[[i]] = raw$X
 		beta[[i]] = raw$beta
 		grid[[i]] = raw$grid
+		if (is(d$data, "Spatial"))
+			projected = is.projected(d$data)
 		if (d$degree != 0)
 			stop("degree != 0: residual variograms wrt coord trend using degree not supported")
 	}
 	names(y) = names(locations) = names(X) = names(object$data)
 	# call variogram.default() next:
-	variogram(y, locations, X, trend.beta = beta, grid = grid, g = object, ...)
+	variogram(y, locations, X, trend.beta = beta, grid = grid, g = object, ...,
+		projected = projected)
 }
